==> accounting-manager-1.13.0-20210416.092343-1-servicearchive.tar.gz: CHANGELOG.md <==
This project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

# Changelog for "dataminer-manager"


## [v1-13-0-SNAPSHOT] - 2021-03-23

### Features

- Migrate accounting-manager to postgresql persistence [#21013]



## [v1-12-0] - 2019-05-02

### Features

- Added autocomplete combo scope and fixed scope list view width



## [v1-11-0] - 2018-12-28

### Features

- Added scope selection [#10188]



## [v1-10-0] - 2018-10-01

### Features

- Updated to StorageHub [#12474]



## [v1-9-1] - 2018-04-11

### Features

- Updated log level to debug [#11259]



## [v1-9-0] - 2017-11-20

### Features

- Updated to support Operation Count as default in all charts



## [v1-8-0] - 2017-10-01

### Features

- Updated to new version of accounting client library



## [v1-7-0] - 2017-06-12

### Features

- Added Spaces chart [#8397]



## [v1-6-0] - 2017-02-28

### Features

- Fixed download in case of multitab on different scopes



## [v1-5-0] - 2016-12-01

### Features

- Added Context Chart
- Added Cache
- Updated to PortalContext



## [v1-4-0] - 2016-10-01

### Features

- Updated to AUTH2.0
- Added Job
- Added configuration by generic resource



## [v1-3-0] - 2016-07-15

### Features

- Added CSV download [Ticket #4041]
- Added Show Others option
- Updated to Liferay 6.2



## [v1-2-0] - 2016-05-01

### Features

- Added Top N Chart[#2251]
- Fixed back button behavior[#3251]



## [v1-1-0] - 2016-01-31

### Features

- Added to Storage Accounting more formats for DataVolume axis [#1831]
- Fixed on Storage Accounting the popup validation on filters [#1832]
- Fixed library dependencies



## [v1-0-0] - 2015-10-15

### Features

- First Release

==> accounting-manager-1.14.0-servicearchive.tar.gz: CHANGELOG.md <==
This project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

# Changelog for "accounting-manager"


## [v1.14.0] - 2021-06-28

### Fixes

- Fixed display errors generated in Root scope [#21729]



## [v1.13.0] - 2021-03-23

### Features

- Migrate accounting-manager to postgresql persistence [#21013]



## [v1.12.0] - 2019-05-02

### Features

- Added autocomplete combo scope and fixed scope list view width



## [v1.11.0] - 2018-12-28

### Features

- Added scope selection [#10188]



## [v1.10.0] - 2018-10-01

### Features

- Updated to StorageHub [#12474]



## [v1.9.1] - 2018-04-11

### Features

- Updated log level to debug [#11259]



## [v1.9.0] - 2017-11-20

### Features

- Updated to support Operation Count as default in all charts



## [v1.8.0] - 2017-10-01

### Features

- Updated to new version of accounting client library



## [v1.7.0] - 2017-06-12

### Features

- Added Spaces chart [#8397]



## [v1.6.0] - 2017-02-28

### Features

- Fixed download in case of multitab on different scopes



## [v1.5.0] - 2016-12-01

### Features

- Added Context Chart
- Added Cache
- Updated to PortalContext



## [v1.4.0] - 2016-10-01

### Features

- Updated to AUTH2.0
- Added Job
- Added configuration by generic resource



## [v1.3.0] - 2016-07-15

### Features

- Added CSV download [Ticket #4041]
- Added Show Others option
- Updated to Liferay 6.2



## [v1.2.0] - 2016-05-01

### Features

- Added Top N Chart[#2251]
- Fixed back button behavior[#3251]



## [v1.1.0] - 2016-01-31

### Features

- Added to Storage Accounting more formats for DataVolume axis [#1831]
- Fixed on Storage Accounting the popup validation on filters [#1832]
- Fixed library dependencies



## [v1.0.0] - 2015-10-15

### Features

- First Release
